USDA PLANTS Database
====================

The `PLANTS`_ (Plant List of Attributes, Names, Taxonomy, and Symbols)
Database provides standardized information about the vascular plants,
mosses, liverworts, hornworts, and lichens of the U.S. and its
territories.

.. _PLANTS: https://plants.usda.gov/home
